@@ -1,5 +1,12 @@
 <?php
-// $Horde: forwards/main.php,v 1.1.1.1.2.4 2002/10/09 04:28:59 ericr Exp $
+/**
+ * $Horde: forwards/main.php,v 1.1.1.1.2.10 2004/03/26 22:43:23 jan Exp $
+ *
+ * Copyright 2001-2004 Eric Rostetter <eric.rostetter@physics.utexas.edu>
+ *
+ * See the enclosed file LICENSE for license information (BSD). If you
+ * did not receive this file, see http://www.horde.org/bsdl.php.
+ */
 
 define('FORWARDS_BASE', dirname(__FILE__));
 include_once FORWARDS_BASE . '/lib/base.php';
@@ -21,7 +28,7 @@ $submit=Horde::getFormData('submit', false);
 if ( $submit ) {
     $forwardmode=Horde::getFormData('mode', "error");
     if ($forwardmode === "error") {
-        Horde::raiseMessage(_("You must specify the mode"),
+        Horde::raiseMessage(_("You must specify the mode (set or remove)"),
                             HORDE_WARNING);
     }
 
@@ -39,11 +46,12 @@ if ( $submit ) {
     }
 
     $metoo=Horde::getFormData('metoo', false);
-    if ($metoo != "on") $metoo = "off";
+    if ($metoo != "on") {
+        $metoo = "off";
+    }
 
+    // Do the function requested
     switch ($forwardmode) {
-    case "error":
-        break;
 
     case "set":
         $forwardwhere=Horde::getFormData('where', false);
@@ -73,9 +81,18 @@ if ( $submit ) {
     }
 }
 
+// If we can tell if the forwards are enabled, then say so. But if
+// this fails, it could be because it is disabled, or just because we
+// can't tell, so just be quiet about it.
+if ($driver->isEnabledForwarding($user, $realm, Auth::getCredential('password'))) {
+            Horde::raiseMessage( _("Forwarding is currently enabled."),
+                    HORDE_ERROR);
+}
+
     include_once $registry->getTemplatePath('horde') . '/javascript/open_help_win.js';
     require $registry->getTemplatePath() . '/common-header.inc';
     require $registry->getFileRoot() . '/status.php';
-    require $registry->getTemplatePath() . '/main.inc';
+    require $registry->getTemplatePath() . '/main/javascript.inc';
+    require $registry->getTemplatePath() . '/main/main.inc';
     require $registry->getTemplatePath() . '/common-footer.inc';
 ?>
