@@ -1,20 +1,17 @@
 <?php
 /*
- * $Horde: forwards/menu.php,v 1.1.1.1.2.1 2002/10/07 01:26:09 ericr Exp $
+ * $Horde: forwards/menu.php,v 1.1.1.1.2.4 2004/03/26 22:43:23 jan Exp $
  *
- * Copyright 1999-2002 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2002 Jon Parise <jon@horde.org>
+ * Copyright 2001-2004 Eric Rostetter <eric.rostetter@physics.utexas.edu>
  *
- * See the enclosed file COPYING for license information (GPL).  If you
- * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ * See the enclosed file LICENSE for license information (BSD). If you
+ * did not receive this file, see http://www.horde.org/bsdl.php.
  */
 
 define('FORWARDS_BASE', dirname(__FILE__));
 include_once FORWARDS_BASE . '/lib/base.php';
 require_once HORDE_BASE . '/lib/Menu.php';
 
-if ($prefs->getValue("frames_mode")  && ! preg_match("/frames_menu\.php$/", $PHP_SELF)) return;
-
 /* Check for additional site-specific menu items (in config/menu.php). */
 $additional_items = '';
 if (@is_readable(FORWARDS_BASE . '/config/menu.php')) {
